@@ -15,12 +15,34 @@ RSpec.describe FaradayMiddleware::Caching do
     end
   end
 
+  let(:test_cache_class) do
+    Class.new(Hash) do
+      def read(key)
+        cached = self[key]
+        return unless cached
+
+        Marshal.load(cached)
+      end
+
+      def write(key, data, _options = nil)
+        self[key] = Marshal.dump(data)
+      end
+
+      def fetch(key)
+        read(key) || yield.tap { |data| write(key, data) }
+      end
+    end
+  end
+
   before do
-    @cache = TestCache.new
+    @cache = test_cache_class.new
     request_count = 0
     response = lambda { |_env|
       [200, { 'Content-Type' => 'text/plain' }, "request:#{request_count += 1}"]
     }
+    not_found = lambda { |_env|
+      [404, { 'Content-Type' => 'text/plain' }, "request:#{request_count += 1}"]
+    }
     broken = lambda { |_env|
       [500, { 'Content-Type' => 'text/plain' }, "request:#{request_count += 1}"]
     }
@@ -35,6 +57,7 @@ RSpec.describe FaradayMiddleware::Caching do
         stub.get('/broken', &broken)
         stub.get('http://www.site-a.com/test', &response)
         stub.get('http://www.site-b.com/test', &response)
+        stub.get('/not_found', &not_found)
       end
     end
   end
@@ -76,6 +99,40 @@ RSpec.describe FaradayMiddleware::Caching do
     expect(get('/broken').body).to eq('request:2')
   end
 
+  context ':cacheable_status_code' do
+    let(:options) { { status_codes: %w[404] } }
+
+    it 'caches requests based on defined cacheable_status_code' do
+      expect(get('/').body).to eq('request:1')
+      expect(get('/not_found').body).to eq('request:2')
+      expect(get('/').body).to eq('request:3')
+      expect(get('/not_found').body).to eq('request:2')
+    end
+
+    context 'with invalid :cacheable_status_code status' do
+      let(:options) { { status_codes: %w[404,500] } }
+
+      it 'caches requests based on valid defined cacheable_status_code' do
+        expect(get('/not_found').body).to eq('request:1')
+        expect(get('/broken').body).to eq('request:2')
+        expect(get('/not_found').body).to eq('request:1')
+        expect(get('/broken').body).to eq('request:3')
+      end
+    end
+
+    context 'with no valid :cacheable_status_code status' do
+      let(:options) { { status_codes: %w[500] } }
+      it 'caches requests based on default cacheable_status_code' do
+        expect(get('/').body).to eq('request:1')
+        expect(get('/broken').body).to eq('request:2')
+        expect(get('/').body).to eq('request:1')
+        expect(get('/not_found').body).to eq('request:3')
+        expect(get('/not_found').body).to eq('request:3')
+        expect(get('/broken').body).to eq('request:4')
+      end
+    end
+  end
+
   context ':ignore_params' do
     let(:options) { { ignore_params: %w[utm_source utm_term] } }
 
@@ -116,30 +173,13 @@ RSpec.describe FaradayMiddleware::Caching do
       end
     end
   end
-
-  class TestCache < Hash
-    def read(key)
-      cached = self[key]
-      return unless cached
-
-      Marshal.load(cached)
-    end
-
-    def write(key, data, _options = nil)
-      self[key] = Marshal.dump(data)
-    end
-
-    def fetch(key)
-      read(key) || yield.tap { |data| write(key, data) }
-    end
-  end
 end
 
 # RackCompatible + Rack::Cache
 RSpec.describe FaradayMiddleware::RackCompatible, 'caching' do
   include FileUtils
 
-  CACHE_DIR = File.expand_path('../tmp/cache', __dir__)
+  let(:cache_dir) { File.expand_path('../tmp/cache', __dir__) }
 
   let(:rack_errors_complainer_middleware) do
     # middleware to check whether "rack.errors" is free of error reports
@@ -157,7 +197,7 @@ RSpec.describe FaradayMiddleware::RackCompatible, 'caching' do
   end
 
   before do
-    rm_r CACHE_DIR if File.exist? CACHE_DIR
+    rm_r(cache_dir) if File.exist?(cache_dir)
     # force reinitializing cache dirs
     Rack::Cache::Storage.instance.clear
 
@@ -173,8 +213,8 @@ RSpec.describe FaradayMiddleware::RackCompatible, 'caching' do
       b.use rack_errors_complainer_middleware
 
       b.use FaradayMiddleware::RackCompatible, Rack::Cache::Context,
-            metastore: "file:#{CACHE_DIR}/rack/meta",
-            entitystore: "file:#{CACHE_DIR}/rack/body",
+            metastore: "file:#{cache_dir}/rack/meta",
+            entitystore: "file:#{cache_dir}/rack/body",
             verbose: true
 
       b.adapter :test do |stub|
@@ -198,7 +238,7 @@ RSpec.describe FaradayMiddleware::RackCompatible, 'caching' do
     expect(response['content-type']).to eq('text/plain')
     expect(response.env[:method]).to eq(:get)
     expect(response.env[:request].respond_to?(:fetch)).to be true
-    expect(response.status). to eq(200)
+    expect(response.status).to eq(200)
 
     expect(post('/').body).to eq('request:2')
   end
